@@ -4,8 +4,9 @@ from urllib.parse import urljoin
 
 
 class RepoScraping(object):
-    def __init__(self, repo_url: str) -> None:
+    def __init__(self, repo_url: str, p: bool = False) -> None:
         self.repo_url = repo_url
+        self.p = p
 
         self.tree_urls = [self.repo_url]
         self.file_urls = []
@@ -19,10 +20,15 @@ class RepoScraping(object):
             soup = BeautifulSoup(r.content, 'html.parser')
 
             for j in soup.find_all('a'):
-                if "tree/master" in j.get('href'):
-                    url = urljoin(self.repo_url, j.get('href'))
-                    if url not in self.tree_urls:
-                        self.tree_urls.append(url)
+                try:
+                    if "tree/master" in j.get('href'):
+                        url = urljoin(self.repo_url, j.get('href'))
+                        if url not in self.tree_urls:
+                            self.tree_urls.append(url)
+                            if self.p:
+                                print(url)
+                except TypeError:
+                    pass
 
     def __prepare_file_urls(self) -> None:
         for tree_url in self.tree_urls:
@@ -34,3 +40,5 @@ class RepoScraping(object):
                     url = urljoin(self.repo_url, i.get('href'))
                     if url not in self.file_urls:
                         self.file_urls.append(url)
+                        if self.p:
+                            print(url)
